@@ -24,7 +24,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.deriv
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyNil)))))), 
          (let coqpp_body f suchthat lemma
-         () = Vernacextend.vtopenproof (fun () -> (
+         () = Vernactypes.vtopenproof (fun () -> (
 # 27 "plugins/derive/g_derive.mlg"
     Derive.start_deriving f.CAst.v suchthat lemma.CAst.v 
               )) in fun f
