@@ -80,28 +80,10 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "native_cast_no_check"
                                             Tactics.native_cast_no_check c 
                                                 )))]
 
-let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "casetype" ~level:0 ~deprecation:( Deprecation.make ~since:"8.18" ~note:"Use [case] instead." () ) 
-         [(Tacentries.TyML (Tacentries.TyIdent ("casetype", Tacentries.TyArg (
-                                                            Extend.TUentry (Genarg.get_arg_tag wit_constr), 
-                                                            Tacentries.TyNil)), 
-           (fun c ist -> 
-# 62 "plugins/ltac/coretactics.mlg"
-                                Tactics.case_type c 
-           )))]
-
-let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "elimtype" ~level:0 ~deprecation:( Deprecation.make ~since:"8.18" ~note:"Use [elim] instead." () ) 
-         [(Tacentries.TyML (Tacentries.TyIdent ("elimtype", Tacentries.TyArg (
-                                                            Extend.TUentry (Genarg.get_arg_tag wit_constr), 
-                                                            Tacentries.TyNil)), 
-           (fun c ist -> 
-# 66 "plugins/ltac/coretactics.mlg"
-                                Tactics.elim_type c 
-           )))]
-
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "exfalso" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("exfalso", Tacentries.TyNil), 
            (fun ist -> 
-# 70 "plugins/ltac/coretactics.mlg"
+# 62 "plugins/ltac/coretactics.mlg"
                      Tactics.exfalso 
            )))]
 
@@ -110,7 +92,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "lapply" ~level:0
                                                           Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                           Tacentries.TyNil)), 
            (fun c ist -> 
-# 74 "plugins/ltac/coretactics.mlg"
+# 66 "plugins/ltac/coretactics.mlg"
                               Tactics.cut_and_apply c 
            )))]
 
@@ -119,21 +101,21 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "transitivity" ~level:
                                                                 Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                                 Tacentries.TyNil)), 
            (fun c ist -> 
-# 78 "plugins/ltac/coretactics.mlg"
+# 70 "plugins/ltac/coretactics.mlg"
                                     Tactics.intros_transitivity (Some c) 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "left" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("left", Tacentries.TyNil), 
            (fun ist -> 
-# 84 "plugins/ltac/coretactics.mlg"
+# 76 "plugins/ltac/coretactics.mlg"
                   Tactics.left_with_bindings false NoBindings 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eleft" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("eleft", Tacentries.TyNil), 
            (fun ist -> 
-# 88 "plugins/ltac/coretactics.mlg"
+# 80 "plugins/ltac/coretactics.mlg"
                    Tactics.left_with_bindings true NoBindings 
            )))]
 
@@ -143,7 +125,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "left_with" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                         Tacentries.TyNil))), 
            (fun bl ist -> 
-# 92 "plugins/ltac/coretactics.mlg"
+# 84 "plugins/ltac/coretactics.mlg"
                                      
     Tacticals.tclDELAYEDWITHHOLES false bl (fun bl -> Tactics.left_with_bindings false bl)
   
@@ -155,7 +137,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eleft_with" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                          Tacentries.TyNil))), 
            (fun bl ist -> 
-# 98 "plugins/ltac/coretactics.mlg"
+# 90 "plugins/ltac/coretactics.mlg"
                                       
     Tacticals.tclDELAYEDWITHHOLES true bl (fun bl -> Tactics.left_with_bindings true bl)
   
@@ -164,14 +146,14 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eleft_with" ~level:0
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "right" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("right", Tacentries.TyNil), 
            (fun ist -> 
-# 106 "plugins/ltac/coretactics.mlg"
+# 98 "plugins/ltac/coretactics.mlg"
                    Tactics.right_with_bindings false NoBindings 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eright" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("eright", Tacentries.TyNil), 
            (fun ist -> 
-# 110 "plugins/ltac/coretactics.mlg"
+# 102 "plugins/ltac/coretactics.mlg"
                     Tactics.right_with_bindings true NoBindings 
            )))]
 
@@ -181,7 +163,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "right_with" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                          Tacentries.TyNil))), 
            (fun bl ist -> 
-# 114 "plugins/ltac/coretactics.mlg"
+# 106 "plugins/ltac/coretactics.mlg"
                                       
     Tacticals.tclDELAYEDWITHHOLES false bl (fun bl -> Tactics.right_with_bindings false bl)
   
@@ -193,7 +175,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eright_with" ~level:0
                                                           Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                           Tacentries.TyNil))), 
            (fun bl ist -> 
-# 120 "plugins/ltac/coretactics.mlg"
+# 112 "plugins/ltac/coretactics.mlg"
                                        
     Tacticals.tclDELAYEDWITHHOLES true bl (fun bl -> Tactics.right_with_bindings true bl)
   
@@ -202,14 +184,14 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eright_with" ~level:0
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "constructor" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("constructor", Tacentries.TyNil), 
            (fun ist -> 
-# 128 "plugins/ltac/coretactics.mlg"
+# 120 "plugins/ltac/coretactics.mlg"
                          Tactics.any_constructor false None 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("constructor", Tacentries.TyArg (
                                                               Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var), 
                                                               Tacentries.TyNil)), 
           (fun i ist -> 
-# 129 "plugins/ltac/coretactics.mlg"
+# 121 "plugins/ltac/coretactics.mlg"
                                       
     Tactics.constructor_tac false None i NoBindings
   
@@ -221,7 +203,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "constructor" ~level:0
                                                               Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                               Tacentries.TyNil)))), 
           (fun i bl ist -> 
-# 132 "plugins/ltac/coretactics.mlg"
+# 124 "plugins/ltac/coretactics.mlg"
                                                           
     let tac bl = Tactics.constructor_tac false None i bl in
     Tacticals.tclDELAYEDWITHHOLES false bl tac
@@ -231,14 +213,14 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "constructor" ~level:0
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "econstructor" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("econstructor", Tacentries.TyNil), 
            (fun ist -> 
-# 139 "plugins/ltac/coretactics.mlg"
+# 131 "plugins/ltac/coretactics.mlg"
                           Tactics.any_constructor true None 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("econstructor", Tacentries.TyArg (
                                                                Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var), 
                                                                Tacentries.TyNil)), 
           (fun i ist -> 
-# 140 "plugins/ltac/coretactics.mlg"
+# 132 "plugins/ltac/coretactics.mlg"
                                        
     Tactics.constructor_tac true None i NoBindings
   
@@ -250,7 +232,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "econstructor" ~level:
                                                                Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                                Tacentries.TyNil)))), 
           (fun i bl ist -> 
-# 143 "plugins/ltac/coretactics.mlg"
+# 135 "plugins/ltac/coretactics.mlg"
                                                            
     let tac bl = Tactics.constructor_tac true None i bl in
     Tacticals.tclDELAYEDWITHHOLES true bl tac
@@ -262,7 +244,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "specialize" ~level:0
                                                               Extend.TUentry (Genarg.get_arg_tag wit_constr_with_bindings), 
                                                               Tacentries.TyNil)), 
            (fun c ist -> 
-# 152 "plugins/ltac/coretactics.mlg"
+# 144 "plugins/ltac/coretactics.mlg"
                                                
     Tacticals.tclDELAYEDWITHHOLES false c (fun c -> Tactics.specialize c None)
   
@@ -274,7 +256,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "specialize" ~level:0
                                                              Extend.TUentry (Genarg.get_arg_tag wit_simple_intropattern), 
                                                              Tacentries.TyNil)))), 
           (fun c ipat ist -> 
-# 155 "plugins/ltac/coretactics.mlg"
+# 147 "plugins/ltac/coretactics.mlg"
                                                                               
     Tacticals.tclDELAYEDWITHHOLES false c (fun c -> Tactics.specialize c (Some ipat))
   
@@ -283,7 +265,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "specialize" ~level:0
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "symmetry" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("symmetry", Tacentries.TyNil), 
            (fun ist -> 
-# 161 "plugins/ltac/coretactics.mlg"
+# 153 "plugins/ltac/coretactics.mlg"
                       Tactics.intros_symmetry {onhyps=Some[];concl_occs=AllOccurrences} 
            )))]
 
@@ -293,21 +275,21 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "symmetry_in" ~level:0
                                                             Extend.TUentry (Genarg.get_arg_tag wit_in_clause), 
                                                             Tacentries.TyNil))), 
            (fun cl ist -> 
-# 165 "plugins/ltac/coretactics.mlg"
+# 157 "plugins/ltac/coretactics.mlg"
                                          Tactics.intros_symmetry cl 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "split" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("split", Tacentries.TyNil), 
            (fun ist -> 
-# 171 "plugins/ltac/coretactics.mlg"
+# 163 "plugins/ltac/coretactics.mlg"
                    Tactics.split_with_bindings false [NoBindings] 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "esplit" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("esplit", Tacentries.TyNil), 
            (fun ist -> 
-# 175 "plugins/ltac/coretactics.mlg"
+# 167 "plugins/ltac/coretactics.mlg"
                     Tactics.split_with_bindings true [NoBindings] 
            )))]
 
@@ -317,7 +299,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "split_with" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                          Tacentries.TyNil))), 
            (fun bl ist -> 
-# 179 "plugins/ltac/coretactics.mlg"
+# 171 "plugins/ltac/coretactics.mlg"
                                       
     Tacticals.tclDELAYEDWITHHOLES false bl (fun bl -> Tactics.split_with_bindings false [bl])
   
@@ -329,7 +311,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "esplit_with" ~level:0
                                                           Extend.TUentry (Genarg.get_arg_tag wit_bindings), 
                                                           Tacentries.TyNil))), 
            (fun bl ist -> 
-# 185 "plugins/ltac/coretactics.mlg"
+# 177 "plugins/ltac/coretactics.mlg"
                                        
     Tacticals.tclDELAYEDWITHHOLES true bl (fun bl -> Tactics.split_with_bindings true [bl])
   
@@ -338,7 +320,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "esplit_with" ~level:0
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "exists" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("exists", Tacentries.TyNil), 
            (fun ist -> 
-# 191 "plugins/ltac/coretactics.mlg"
+# 183 "plugins/ltac/coretactics.mlg"
                     Tactics.split_with_bindings false [NoBindings] 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("exists", Tacentries.TyArg (
@@ -346,14 +328,14 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "exists" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_bindings), ","), 
                                                          Tacentries.TyNil)), 
           (fun bll ist -> 
-# 192 "plugins/ltac/coretactics.mlg"
+# 184 "plugins/ltac/coretactics.mlg"
                                                    Tactics.split_with_delayed_bindings false bll 
           )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eexists" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("eexists", Tacentries.TyNil), 
            (fun ist -> 
-# 196 "plugins/ltac/coretactics.mlg"
+# 188 "plugins/ltac/coretactics.mlg"
                      Tactics.split_with_bindings true [NoBindings] 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("eexists", Tacentries.TyArg (
@@ -361,7 +343,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "eexists" ~level:0
                                                           Extend.TUentry (Genarg.get_arg_tag wit_bindings), ","), 
                                                           Tacentries.TyNil)), 
           (fun bll ist -> 
-# 197 "plugins/ltac/coretactics.mlg"
+# 189 "plugins/ltac/coretactics.mlg"
                                                     Tactics.split_with_delayed_bindings true bll 
           )))]
 
@@ -371,21 +353,21 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intros_until" ~level:
                                                           Extend.TUentry (Genarg.get_arg_tag wit_quantified_hypothesis), 
                                                           Tacentries.TyNil))), 
            (fun h ist -> 
-# 203 "plugins/ltac/coretactics.mlg"
+# 195 "plugins/ltac/coretactics.mlg"
                                                      Tactics.intros_until h 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyNil), 
            (fun ist -> 
-# 207 "plugins/ltac/coretactics.mlg"
+# 199 "plugins/ltac/coretactics.mlg"
                    Tactics.intro_move None MoveLast 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyArg (
                                                         Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                         Tacentries.TyNil)), 
           (fun id ist -> 
-# 208 "plugins/ltac/coretactics.mlg"
+# 200 "plugins/ltac/coretactics.mlg"
                              Tactics.intro_move (Some id) MoveLast 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyArg (
@@ -394,7 +376,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0
                                                         Tacentries.TyIdent ("top", 
                                                         Tacentries.TyNil)))), 
           (fun id ist -> 
-# 209 "plugins/ltac/coretactics.mlg"
+# 201 "plugins/ltac/coretactics.mlg"
                                         Tactics.intro_move (Some id) MoveFirst 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyArg (
@@ -403,7 +385,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0
                                                         Tacentries.TyIdent ("bottom", 
                                                         Tacentries.TyNil)))), 
           (fun id ist -> 
-# 210 "plugins/ltac/coretactics.mlg"
+# 202 "plugins/ltac/coretactics.mlg"
                                            Tactics.intro_move (Some id) MoveLast 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyArg (
@@ -413,7 +395,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                         Tacentries.TyNil)))), 
           (fun id h ist -> 
-# 211 "plugins/ltac/coretactics.mlg"
+# 203 "plugins/ltac/coretactics.mlg"
                                             Tactics.intro_move (Some id) (MoveAfter h) 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyArg (
@@ -423,21 +405,21 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                         Tacentries.TyNil)))), 
           (fun id h ist -> 
-# 212 "plugins/ltac/coretactics.mlg"
+# 204 "plugins/ltac/coretactics.mlg"
                                              Tactics.intro_move (Some id) (MoveBefore h) 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyIdent ("at", 
                                                         Tacentries.TyIdent ("top", 
                                                         Tacentries.TyNil))), 
           (fun ist -> 
-# 213 "plugins/ltac/coretactics.mlg"
+# 205 "plugins/ltac/coretactics.mlg"
                               Tactics.intro_move None MoveFirst 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyIdent ("at", 
                                                         Tacentries.TyIdent ("bottom", 
                                                         Tacentries.TyNil))), 
           (fun ist -> 
-# 214 "plugins/ltac/coretactics.mlg"
+# 206 "plugins/ltac/coretactics.mlg"
                                  Tactics.intro_move None MoveLast 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyIdent ("after", 
@@ -445,7 +427,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                         Tacentries.TyNil))), 
           (fun h ist -> 
-# 215 "plugins/ltac/coretactics.mlg"
+# 207 "plugins/ltac/coretactics.mlg"
                                   Tactics.intro_move None (MoveAfter h) 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("intro", Tacentries.TyIdent ("before", 
@@ -453,7 +435,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "intro" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                         Tacentries.TyNil))), 
           (fun h ist -> 
-# 216 "plugins/ltac/coretactics.mlg"
+# 208 "plugins/ltac/coretactics.mlg"
                                    Tactics.intro_move None (MoveBefore h) 
           )))]
 
@@ -464,7 +446,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "move" ~level:0
                                                         Tacentries.TyIdent ("top", 
                                                         Tacentries.TyNil)))), 
            (fun id ist -> 
-# 222 "plugins/ltac/coretactics.mlg"
+# 214 "plugins/ltac/coretactics.mlg"
                                      Tactics.move_hyp id MoveFirst 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("move", Tacentries.TyArg (
@@ -473,7 +455,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "move" ~level:0
                                                        Tacentries.TyIdent ("bottom", 
                                                        Tacentries.TyNil)))), 
           (fun id ist -> 
-# 223 "plugins/ltac/coretactics.mlg"
+# 215 "plugins/ltac/coretactics.mlg"
                                         Tactics.move_hyp id MoveLast 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("move", Tacentries.TyArg (
@@ -483,7 +465,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "move" ~level:0
                                                        Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                        Tacentries.TyNil)))), 
           (fun id h ist -> 
-# 224 "plugins/ltac/coretactics.mlg"
+# 216 "plugins/ltac/coretactics.mlg"
                                          Tactics.move_hyp id (MoveAfter h) 
           )));
          (Tacentries.TyML (Tacentries.TyIdent ("move", Tacentries.TyArg (
@@ -493,7 +475,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "move" ~level:0
                                                        Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                        Tacentries.TyNil)))), 
           (fun id h ist -> 
-# 225 "plugins/ltac/coretactics.mlg"
+# 217 "plugins/ltac/coretactics.mlg"
                                           Tactics.move_hyp id (MoveBefore h) 
           )))]
 
@@ -503,7 +485,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "rename" ~level:0
                                                           Extend.TUentry (Genarg.get_arg_tag wit_rename), ","), 
                                                           Tacentries.TyNil)), 
            (fun ids ist -> 
-# 231 "plugins/ltac/coretactics.mlg"
+# 223 "plugins/ltac/coretactics.mlg"
                                                  Tactics.rename_hyp ids 
            )))]
 
@@ -513,12 +495,12 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "revert" ~level:0
                                                           Extend.TUentry (Genarg.get_arg_tag wit_hyp)), 
                                                           Tacentries.TyNil)), 
            (fun hl ist -> 
-# 237 "plugins/ltac/coretactics.mlg"
-                                    Tactics.revert hl 
+# 229 "plugins/ltac/coretactics.mlg"
+                                    Generalize.revert hl 
            )))]
 
 
-# 242 "plugins/ltac/coretactics.mlg"
+# 234 "plugins/ltac/coretactics.mlg"
  
 
 let simple_induct h =
@@ -533,12 +515,12 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "simple_induction" ~le
                                                           Extend.TUentry (Genarg.get_arg_tag wit_quantified_hypothesis), 
                                                           Tacentries.TyNil))), 
            (fun h ist -> 
-# 251 "plugins/ltac/coretactics.mlg"
+# 243 "plugins/ltac/coretactics.mlg"
                                                          simple_induct h 
            )))]
 
 
-# 254 "plugins/ltac/coretactics.mlg"
+# 246 "plugins/ltac/coretactics.mlg"
  
 
 let simple_destruct h =
@@ -553,14 +535,14 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "simple_destruct" ~lev
                                                           Extend.TUentry (Genarg.get_arg_tag wit_quantified_hypothesis), 
                                                           Tacentries.TyNil))), 
            (fun h ist -> 
-# 263 "plugins/ltac/coretactics.mlg"
+# 255 "plugins/ltac/coretactics.mlg"
                                                         simple_destruct h 
            )))]
 
 let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "admit" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("admit", Tacentries.TyNil), 
            (fun ist -> 
-# 269 "plugins/ltac/coretactics.mlg"
+# 261 "plugins/ltac/coretactics.mlg"
                   Proofview.give_up 
            )))]
 
@@ -571,7 +553,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "fix" ~level:0
                                                        Extend.TUentry (Genarg.get_arg_tag wit_natural), 
                                                        Tacentries.TyNil))), 
            (fun id n ist -> 
-# 275 "plugins/ltac/coretactics.mlg"
+# 267 "plugins/ltac/coretactics.mlg"
                                       Tactics.fix id n 
            )))]
 
@@ -580,7 +562,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "cofix" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                          Tacentries.TyNil)), 
            (fun id ist -> 
-# 281 "plugins/ltac/coretactics.mlg"
+# 273 "plugins/ltac/coretactics.mlg"
                              Tactics.cofix id 
            )))]
 
@@ -590,7 +572,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "clear" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_hyp)), 
                                                          Tacentries.TyNil)), 
            (fun ids ist -> 
-# 287 "plugins/ltac/coretactics.mlg"
+# 279 "plugins/ltac/coretactics.mlg"
                                 
     if List.is_empty ids then Tactics.keep []
     else Tactics.clear ids
@@ -602,7 +584,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "clear" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_hyp)), 
                                                         Tacentries.TyNil))), 
           (fun ids ist -> 
-# 291 "plugins/ltac/coretactics.mlg"
+# 283 "plugins/ltac/coretactics.mlg"
                                         Tactics.keep ids 
           )))]
 
@@ -612,7 +594,7 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "clearbody" ~level:0
                                                              Extend.TUentry (Genarg.get_arg_tag wit_hyp)), 
                                                              Tacentries.TyNil)), 
            (fun ids ist -> 
-# 297 "plugins/ltac/coretactics.mlg"
+# 289 "plugins/ltac/coretactics.mlg"
                                         Tactics.clear_body ids 
            )))]
 
@@ -622,12 +604,12 @@ let () = Tacentries.tactic_extend "coq-core.plugins.ltac" "generalize_dependent"
                                                               Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                               Tacentries.TyNil))), 
            (fun c ist -> 
-# 303 "plugins/ltac/coretactics.mlg"
-                                              Tactics.generalize_dep c 
+# 295 "plugins/ltac/coretactics.mlg"
+                                              Generalize.generalize_dep c 
            )))]
 
 
-# 308 "plugins/ltac/coretactics.mlg"
+# 300 "plugins/ltac/coretactics.mlg"
  
 
 open Tacexpr
@@ -639,7 +621,7 @@ let initial_atomic () =
     Tacenv.register_ltac false false (Names.Id.of_string s) body
   in
   let () = List.iter iter
-      [ "red", TacReduce(Red false,nocl);
+      [ "red", TacReduce (Red, nocl);
         "hnf", TacReduce(Hnf,nocl);
         "simpl", TacReduce(Simpl (Redops.all_flags,None),nocl);
         "compute", TacReduce(Cbv Redops.all_flags,nocl);
