@@ -16,7 +16,7 @@ let tuto_warn = CWarnings.create ~name:"name" ~category:cat
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto0") ~command:"HelloWorld" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("HelloWorld", 
                                      Vernacextend.TyNil), (let coqpp_body () = 
-                                                          Vernacextend.vtdefault (fun () -> 
+                                                          Vernactypes.vtdefault (fun () -> 
                                                           
 # 22 "doc/plugin_tutorial/tuto0/src/g_tuto0.mlg"
                         Feedback.msg_notice (strbrk Tuto0_main.message) 
@@ -34,7 +34,7 @@ let () = Tacentries.tactic_extend "coq-plugin-tutorial.tuto0" "hello_world_tacti
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto0") ~command:"HelloWarning" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("HelloWarning", 
                                      Vernacextend.TyNil), (let coqpp_body () = 
-                                                          Vernacextend.vtdefault (fun () -> 
+                                                          Vernactypes.vtdefault (fun () -> 
                                                           
 # 43 "doc/plugin_tutorial/tuto0/src/g_tuto0.mlg"
     
@@ -56,7 +56,7 @@ let () = Tacentries.tactic_extend "coq-plugin-tutorial.tuto0" "hello_warning_tac
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto0") ~command:"HelloError" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("HelloError", 
                                      Vernacextend.TyNil), (let coqpp_body () = 
-                                                          Vernacextend.vtdefault (fun () -> 
+                                                          Vernactypes.vtdefault (fun () -> 
                                                           
 # 66 "doc/plugin_tutorial/tuto0/src/g_tuto0.mlg"
                         CErrors.user_err (str Tuto0_main.message) 
