@@ -20,7 +20,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("What's", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.vtdefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 39 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -39,7 +39,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_string), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body s () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body s () = Vernactypes.vtdefault (fun () -> 
 # 45 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input s strbrk "string" 
                                 ) in fun s
@@ -52,7 +52,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_int), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body i () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body i () = Vernactypes.vtdefault (fun () -> 
 # 47 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input i Pp.int "int" 
                                 ) in fun i
@@ -65,11 +65,10 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body id
-         () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body id () = Vernactypes.vtdefault (fun () -> 
 # 49 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input id Ppconstr.pr_id "identifier" 
-              ) in fun id
+                                 ) in fun id
          ?loc ~atts () -> coqpp_body id
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("What", 
@@ -79,7 +78,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_reference), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body r () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body r () = Vernactypes.vtdefault (fun () -> 
 # 51 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input r Ppconstr.pr_qualid "reference" 
                                 ) in fun r
@@ -95,7 +94,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                     Vernacextend.TyTerminal ("list", 
                                                                     Vernacextend.TyTerminal ("of", 
                                                                     Vernacextend.TyNil)))))), 
-         (let coqpp_body l () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body l () = Vernactypes.vtdefault (fun () -> 
 # 60 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let print l = str "[" ++ Pp.prlist_with_sep (fun () -> str ";") Pp.int l ++ str "]" in
@@ -109,7 +108,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_int)), 
                                                                    Vernacextend.TyTerminal ("nonempty", 
                                                                    Vernacextend.TyNil))), 
-         (let coqpp_body l () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body l () = Vernactypes.vtdefault (fun () -> 
 # 65 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let print l = str "[" ++ Pp.prlist_with_sep (fun () -> str ";") Pp.int l ++ str "]" in
@@ -124,7 +123,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_int)), 
                                                                     Vernacextend.TyTerminal ("provided", 
                                                                     Vernacextend.TyNil)))), 
-         (let coqpp_body o () = Vernacextend.vtdefault (fun () -> 
+         (let coqpp_body o () = Vernactypes.vtdefault (fun () -> 
 # 70 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let print o = strbrk (if Option.has_some o then "Yes" else "No") in
@@ -138,7 +137,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Intern", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.vtdefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 116 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -163,7 +162,7 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                                     Vernacextend.TyNil)))), 
          (let coqpp_body i e
-         poly = Vernacextend.vtdefault (fun () -> 
+         poly = Vernactypes.vtdefault (fun () -> 
 # 151 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let env = Global.env () in
@@ -174,26 +173,29 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
      Feedback.msg_notice (print r)
    
                 ) in fun i
-         e ?loc ~atts () -> coqpp_body i e
-         (Attributes.parse Attributes.polymorphic atts)), None))]
+         e ?loc ~atts () -> coqpp_body i e (Attributes.parse 
+# 150 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+             Attributes.polymorphic
+          atts)), None))]
 
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"ExamplePrint" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("MyPrint", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
                                      Vernacextend.TyNil)), (let coqpp_body r
-                                                           () = Vernacextend.vtdefault (fun () -> 
+                                                           () = Vernactypes.vtopaqueaccess (fun ~opaque_access -> (
                                                                 
-# 173 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
-    
+# 177 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+     fun ~opaque_access ->
      let env = Global.env () in
      let sigma = Evd.from_env env in
      try
-       let t = Simple_print.simple_body_access (Nametab.global r) in
+       let t = Simple_print.simple_body_access ~opaque_access (Nametab.global r) in
        Feedback.msg_notice (Printer.pr_econstr_env env sigma t)
      with Failure s ->
        CErrors.user_err (str s)
    
-                                                                ) in fun r
+                                                                )
+                                                                ~opaque_access) in fun r
                                                            ?loc ~atts ()
                                                            -> coqpp_body r
                                                            (Attributes.unsupported_attributes atts)), None))]
@@ -205,9 +207,9 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                                     Vernacextend.TyNil)))), 
          (let coqpp_body i e
-         poly = Vernacextend.vtdefault (fun () -> 
-# 199 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
-    
+         poly = Vernactypes.vtopaqueaccess (fun ~opaque_access -> (
+# 205 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+     fun ~opaque_access ->
      let env = Global.env () in
      let sigma = Evd.from_env env in
      let (sigma, t) = Constrintern.interp_constr_evars env sigma e in
@@ -216,21 +218,23 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
      Feedback.msg_notice (print r);
      let env = Global.env () in
      let sigma = Evd.from_env env in
-     let t = Simple_print.simple_body_access r in
+     let t = Simple_print.simple_body_access ~opaque_access r in
      let print t = strbrk "Found " ++ Printer.pr_econstr_env env sigma t in
      Feedback.msg_notice (print t)
    
-                ) in fun i
-         e ?loc ~atts () -> coqpp_body i e
-         (Attributes.parse Attributes.polymorphic atts)), None))]
+                ) ~opaque_access) in fun i
+         e ?loc ~atts () -> coqpp_body i e (Attributes.parse 
+# 204 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+             Attributes.polymorphic
+          atts)), None))]
 
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Check1" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Check1", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.vtdefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
-# 223 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+# 229 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let env = Global.env () in
      let sigma = Evd.from_env env in
@@ -247,9 +251,9 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Check2", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.vtdefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
-# 234 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+# 240 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let env = Global.env () in
      let sigma = Evd.from_env env in
@@ -268,9 +272,9 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tu
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil))), (let coqpp_body e1
                                                             e2
-                                                            () = Vernacextend.vtdefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
-# 252 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+# 258 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let env = Global.env () in
      let sigma = Evd.from_env env in
@@ -293,16 +297,16 @@ let () = Tacentries.tactic_extend "coq-plugin-tutorial.tuto1" "my_intro" ~level:
                                                             Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                             Tacentries.TyNil)), 
            (fun i ist -> 
-# 273 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+# 279 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     Tactics.introduction i 
            )))]
 
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"ExploreProof" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("ExploreProof", 
                                      Vernacextend.TyNil), (let coqpp_body () = 
-                                                          Vernacextend.vtreadproof (fun ~pstate -> (
+                                                          Vernactypes.vtreadproof (fun ~pstate -> (
                                                           
-# 288 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
+# 294 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     fun ~pstate ->
     let sigma, env = Declare.Proof.get_current_context pstate in
     let pprf = Proof.partial_proof (Declare.Proof.get pstate) in
